containertools.replace_larger_left_half_of_elements_in_container_with_big_endian_rests
======================================================================================

.. autofunction:: abjad.tools.containertools.replace_larger_left_half_of_elements_in_container_with_big_endian_rests.replace_larger_left_half_of_elements_in_container_with_big_endian_rests
